Github messages for voidlinux
 help / color / mirror / Atom feed
From: sgn <sgn@users.noreply.github.com>
To: ml@inbox.vuxu.org
Subject: [PR PATCH] build-style/perl-module: respect build_wrksrc 
Date: Wed, 07 Jul 2021 18:30:23 +0200	[thread overview]
Message-ID: <gh-mailinglist-notifications-41a7ca26-5023-4802-975b-f1789d68868e-void-packages-31844@inbox.vuxu.org> (raw)

[-- Attachment #1: Type: text/plain, Size: 1625 bytes --]

There is a new pull request by sgn against master on the void-packages repository

https://github.com/sgn/void-packages perl-module-respect-build-wrksrc
https://github.com/void-linux/void-packages/pull/31844

build-style/perl-module: respect build_wrksrc 
<!-- Mark items with [x] where applicable -->

#### General
- [ ] This is a new package and it conforms to the [quality requirements](https://github.com/void-linux/void-packages/blob/master/Manual.md#quality-requirements)

#### Have the results of the proposed changes been tested?
- [ ] I use the packages affected by the proposed changes on a regular basis and confirm this PR works for me
- [ ] I generally don't use the affected packages but briefly tested this PR

<!--
If GitHub CI cannot be used to validate the build result (for example, if the
build is likely to take several hours), make sure to
[skip CI](https://github.com/void-linux/void-packages/blob/master/CONTRIBUTING.md#continuous-integration).
When skipping CI, uncomment and fill out the following section.
Note: for builds that are likely to complete in less than 2 hours, it is not
acceptable to skip CI.
-->
<!-- 
#### Does it build and run successfully? 
(Please choose at least one native build and, if supported, at least one cross build. More are better.)
- [ ] I built this PR locally for my native architecture, (ARCH-LIBC)
- [ ] I built this PR locally for these architectures (if supported. mark crossbuilds):
  - [ ] aarch64-musl
  - [ ] armv7l
  - [ ] armv6l-musl
-->


A patch file from https://github.com/void-linux/void-packages/pull/31844.patch is attached

[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: github-pr-perl-module-respect-build-wrksrc-31844.patch --]
[-- Type: text/x-diff, Size: 3790 bytes --]

From a66cc98283f98c5832997b6e9f5305d743e58ea0 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=C4=90o=C3=A0n=20Tr=E1=BA=A7n=20C=C3=B4ng=20Danh?=
 <congdanhqx@gmail.com>
Date: Wed, 7 Jul 2021 23:25:31 +0700
Subject: [PATCH 1/2] build-style/perl-module: respect build_wrksrc

`wrksrc` is supposed to be a top-level directory. Should the build
system need to be run inside a sub-directory, `build_wrksrc` should be
used instead. We change to `build_wrksrc` implicitly before `do_build`
and `do_install`.

Let's respect `build_wrksrc` in `perl-module`.
---
 common/build-style/perl-module.sh | 16 +++++++++-------
 1 file changed, 9 insertions(+), 7 deletions(-)

From 43b96f7822f0233baabd9274566d30bf2a56b10f Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=C4=90o=C3=A0n=20Tr=E1=BA=A7n=20C=C3=B4ng=20Danh?=
 <congdanhqx@gmail.com>
Date: Wed, 7 Jul 2021 23:28:29 +0700
Subject: [PATCH 2/2] perl-Barcode-ZBar: correct license

---
 srcpkgs/perl-Barcode-ZBar/template | 15 ++++++---------
 1 file changed, 6 insertions(+), 9 deletions(-)

diff --git a/srcpkgs/perl-Barcode-ZBar/template b/srcpkgs/perl-Barcode-ZBar/template
index 474c2448f089..d3c8fce9049b 100644
--- a/srcpkgs/perl-Barcode-ZBar/template
+++ b/srcpkgs/perl-Barcode-ZBar/template
@@ -1,20 +1,17 @@
 # Template file for 'perl-Barcode-ZBar'
 pkgname=perl-Barcode-ZBar
 version=0.23.1
-revision=1
-wrksrc="zbar-${version}/perl"
+revision=2
+wrksrc="zbar-$version"
+build_wrksrc=perl
 build_style=perl-module
 hostmakedepends="perl"
 makedepends="perl libzbar-devel"
-depends="${makedepends}"
+depends="perl"
 short_desc="Perl interface to the ZBar Barcode Reader"
 maintainer="Leah Neukirchen <leah@vuxu.org>"
-license="LGPL-2.1"
+license="LGPL-2.1-or-later"
 homepage="https://metacpan.org/release/Barcode-ZBar"
 distfiles="https://linuxtv.org/downloads/zbar/zbar-${version}.tar.bz2"
 checksum=dad260b47ef887a639e840a89e5e6e132217b6bba2a8473565d1f459bcb97c1f
-
-do_check() {
-	# Requires X display
-	:
-}
+make_check=no # requires X display

             reply	other threads:[~2021-07-07 16:30 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-07-07 16:30 sgn [this message]
2021-07-08 11:01 ` [PR PATCH] [Merged]: " sgn

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=gh-mailinglist-notifications-41a7ca26-5023-4802-975b-f1789d68868e-void-packages-31844@inbox.vuxu.org \
    --to=sgn@users.noreply.github.com \
    --cc=ml@inbox.vuxu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).
diff --git a/common/build-style/perl-module.sh b/common/build-style/perl-module.sh
index 5b0f0ccde825..b9a01b13cfa9 100644
--- a/common/build-style/perl-module.sh
+++ b/common/build-style/perl-module.sh
@@ -7,7 +7,8 @@
 # 	build_style=perl-module
 #
 # Optionally if the module needs more directories to be configured other
 # than $XBPS_BUILDDIR/$wrksrc, one can use (relative to $wrksrc):
 #
 #	perl_configure_dirs="blob/bob foo/blah"
 #
@@ -29,17 +30,18 @@ do_configure() {
 	fi
 	export PERL5LIB=$perlprefix
 
-	if [ -f "${wrksrc}/Makefile.PL" ]; then
-		sed -i "s,/usr/include,${XBPS_CROSS_BASE}/usr/include,g" "${wrksrc}/Makefile.PL"
+	if [ -f "${wrksrc}/${build_wrksrc:+$build_wrksrc/}Makefile.PL" ]; then
+		sed -i "s,/usr/include,${XBPS_CROSS_BASE}/usr/include,g" \
+		"${wrksrc}/${build_wrksrc:+$build_wrksrc/}Makefile.PL"
 	fi
 
 	if [ -z "$perl_configure_dirs" ]; then
-		perlmkf="$wrksrc/Makefile.PL"
+		perlmkf="$wrksrc/${build_wrksrc:+$build_wrksrc/}Makefile.PL"
 		if [ ! -f "$perlmkf" ]; then
 			msg_error "*** ERROR couldn't find $perlmkf, aborting ***\n"
 		fi
 
-		cd "$wrksrc"
+		cd "$wrksrc/${build_wrksrc:+$build_wrksrc}"
 		PERL_MM_USE_DEFAULT=1 GCC="$CC" CC="$CC" LD="$CC" \
 			OPTIMIZE="$CFLAGS" \
 			CFLAGS="$CFLAGS -I${XBPS_CROSS_BASE}/usr/include" \
@@ -49,9 +51,9 @@ do_configure() {
 	fi
 
 	for i in ${perl_configure_dirs}; do
-		perlmkf="$wrksrc/$i/Makefile.PL"
+		perlmkf="$wrksrc/${build_wrksrc:+$build_wrksrc/}$i/Makefile.PL"
 		if [ -f "$perlmkf" ]; then
-			cd "$wrksrc/$i"
+			cd "$wrksrc/${build_wrksrc:+$build_wrksrc/}$i"
 			PERL_MM_USE_DEFAULT=1 GCC="$CC" CC="$CC" LD="$CC" \
 				OPTIMIZE="$CFLAGS" \
 				CFLAGS="$CFLAGS -I${XBPS_CROSS_BASE}/usr/include" \
@@ -7,7 +7,8 @@
 #
 # Optionally if the module needs more directories to be configured other
-# than $XBPS_BUILDDIR/$wrksrc, one can use (relative to $wrksrc):
+# than $XBPS_BUILDDIR/$wrksrc/$build_wrksrc, one can use (relative to
+# $wrksrc/$build_wrksrc):
 #
 #	perl_configure_dirs="blob/bob foo/blah"
